aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c
diff options
context:
space:
mode:
Diffstat (limited to 'Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c')
-rw-r--r--Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c45
1 files changed, 27 insertions, 18 deletions
diff --git a/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c b/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c
index 3d048a821..6b434ba43 100644
--- a/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c
+++ b/Demos/Host/Incomplete/BluetoothHost/Lib/BluetoothStack.c
@@ -33,27 +33,25 @@
/** Bluetooth device connection information structure. Once connected to a remote device, this structure tracks the
* connection state of the individual L2CAP channels.
*/
-Bluetooth_Connection_t Bluetooth_Connection = {IsConnected: false};
+Bluetooth_Connection_t Bluetooth_Connection = { IsConnected: false };
-/** Bluetooth configuration structure. This structure configures the bluetooth stack's user alterable settings. */
-Bluetooth_Device_t Bluetooth_DeviceConfiguration =
- {
- Class: (DEVICE_CLASS_SERVICE_CAPTURING | DEVICE_CLASS_MAJOR_COMPUTER | DEVICE_CLASS_MINOR_COMPUTER_PALM),
- PINCode: "0000",
- Name: "LUFA Bluetooth Demo"
- };
+/** Bluetooth device state information structure. This structure contains details on the current Bluetooth stack
+ * state.
+ */
+Bluetooth_Stack_State_t Bluetooth_State = { IsInitialized: false };
/** Bluetooth stack initialization function. This function must be called once to initialize the Bluetooth stack,
* ready for connection to remote devices.
*
* \note This function only begins the initialization process; the stack is initialized as the main Bluetooth stack
* management task is repeatedly called. The initialization process ends when the \ref Bluetooth_HCIProcessingState
* global enters the Bluetooth_ProcessEvents state.
*/
void Bluetooth_Stack_Init(void)
{
/* Reset the HCI state machine - this will eventually reset the adapter and stack when the Bluetooth stack task is called */
- Bluetooth_HCIProcessingState = Bluetooth_Init;
+ Bluetooth_State.CurrentHCIState = Bluetooth_Init;
+ Bluetooth_State.NextHCIState = Bluetooth_Init;
}
/** Bluetooth stack management task. This task must be repeatedly called to maintain the Bluetooth stack and any connection
@@ -67,22 +65,33 @@ void Bluetooth_Stack_USBTask(void)
/** Retrieves the channel information structure with the given local or remote channel number from the channel list.
*
- * \param[in] ChannelNumber Channel number to search for in the channel list
- * \param[in] SearchByRemoteChannel Indicated whether to search for a channel information structure by the given remote channel
- * or local channel number
+ * \param[in] SearchValue Value to search for in the channel structure list
+ * \param[in] SearchKey Key to search within the channel structure, a CHANNEL_SEARCH_* mask
*
* \return Pointer to the matching channel information structure in the channel table if found, NULL otherwise
*/
-Bluetooth_Channel_t* Bluetooth_GetChannelData(const uint16_t ChannelNumber, const bool SearchByRemoteChannel)
+Bluetooth_Channel_t* Bluetooth_GetChannelData(const uint16_t SearchValue, const uint8_t SearchKey)
{
for (uint8_t i = 0; i < BLUETOOTH_MAX_OPEN_CHANNELS; i++)
{
Bluetooth_Channel_t* ChannelData = &Bluetooth_Connection.Channels[i];
- /* Fetch the channel number that is to be matched against from the current channel information struct */
- uint16_t SearchChannelNumber = (SearchByRemoteChannel) ? ChannelData->RemoteNumber : ChannelData->LocalNumber;
+ bool FoundMatch = false;
+
+ switch (SearchKey)
+ {
+ case CHANNEL_SEARCH_LOCALNUMBER:
+ FoundMatch = (SearchValue == ChannelData->LocalNumber);
+ break;
+ case CHANNEL_SEARCH_REMOTENUMBER:
+ FoundMatch = (SearchValue == ChannelData->RemoteNumber);
+ break;
+ case CHANNEL_SEARCH_PSM:
+ FoundMatch = (SearchValue == ChannelData->PSM);
+ break;
+ }
- if (SearchChannelNumber == ChannelNumber)
+ if (FoundMatch)
return ChannelData;
}
@@ -33,27 +33,25 @@
*
* \note This function only begins the initialization process; the stack is initialized as the main Bluetooth stack
- * management task is repeatedly called. The initialization process ends when the \ref Bluetooth_HCIProcessingState
- * global enters the Bluetooth_ProcessEvents state.
+ * management task is repeatedly called. The initialization process ends when the IsInitialized element of the
+ * \ref Bluetooth_State structure becomes true and the \ref Bluetooth_StackInitialized() callback fires.
*/
void Bluetooth_Stack_Init(void)